# pyihome

Python library to interface with the iHome API.

Currently this library supports the following:

All Devices
 - get devices associated with the account which are swtiches with only one outlet

Switch
 - turn on
 - turn off
 - get status
